==> inquirer-fuzzy-path-2.3.8.tgz: inquirer-fuzzy-path/README.md <==
# Installation
> `npm install --save @types/inquirer-fuzzy-path`

# Summary
This package contains type definitions for inquirer-fuzzy-path (https://github.com/adelsz/inquirer-fuzzy-path).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/inquirer-fuzzy-path.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/inquirer-fuzzy-path/index.d.ts)
````ts
import { Answers, KeyUnion, QuestionCollection } from "inquirer";
import { AutocompleteQuestionOptions } from "inquirer-autocomplete-prompt";
import InquirerAutocomplete = require("inquirer-autocomplete-prompt");
import { Interface as ReadlineInterface } from "readline";

export = InquirerFuzzyPath;

/**
 * Provides the functionality to create a new Inquirer plugin
 */
declare class InquirerFuzzyPath<T extends Answers> extends InquirerAutocomplete<T> {
    /**
     * Create new InquirerFuzzyPath
     *
     * @param questions
     * The questions to prompt
     * @param rl
     * The readline interface
     * @param answers
     * The currently supplied answers
     */
    constructor(questions: QuestionCollection<T>, rl: ReadlineInterface, answers: Answers);

    /**
     * Curate list of choices.
     *
     * @param searchTerm
     * The term to search for
     */
    search(searchTerm: string): Promise<void>;

    /**
     * When user presses `enter` key
     *
     * @param line
     * The input on the line.
     */
    onSubmit(line: string): void;
}

/**
 * Provides inquirer prompt options for type `InquirerFuzzyPath`.
 */
declare namespace InquirerFuzzyPath {
    /**
     * Provides options for a question of type `InquirerFuzzyPath`.
     *
     * @template T
     * The type of the answers.
     */
    interface FuzzyPathQuestionOptions<T extends Answers = Answers>
        extends Partial<Omit<AutocompleteQuestionOptions<T>, "type">>
    {
        /**
         * The key to save the answer to the answers-hash.
         */
        type: "fuzzypath";

        /**
         * The key to save the answer to the answers-hash.
         */
        name: KeyUnion<T>;

        /**
         * The root search directory, default to ".".
         */
        rootPath?: string | undefined;

        /**
         * A function to exclude some paths from the file-system scan.
         */
        excludePath?: ((path: string) => boolean) | undefined;

        /**
         * A function to exclude some paths from the final list.
         */
        excludeFilter?: ((path: string) => boolean) | undefined;

        /**
         * A string to specify the type of nodes to display, default to "any".
         */
        itemType?: "any" | "directory" | "file" | undefined;

        /**
         * An integer (>= 0) to limit the depth of sub-folders to scan,
         * undefined means infinite.
         */
        depthLimit?: number | undefined;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:35 GMT
 * Dependencies: [@types/inquirer](https://npmjs.com/package/@types/inquirer), [@types/inquirer-autocomplete-prompt](https://npmjs.com/package/@types/inquirer-autocomplete-prompt)

# Credits
These definitions were written by [迷子 (Maiko Tan)](https://github.com/MaikoTan).

==> inquirer-fuzzy-path-2.3.9.tgz: inquirer-fuzzy-path/README.md <==
# Installation
> `npm install --save @types/inquirer-fuzzy-path`

# Summary
This package contains type definitions for inquirer-fuzzy-path (https://github.com/adelsz/inquirer-fuzzy-path).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/inquirer-fuzzy-path.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/inquirer-fuzzy-path/index.d.ts)
````ts
import { Answers, KeyUnion, QuestionCollection } from "inquirer";
import { AutocompleteQuestionOptions } from "inquirer-autocomplete-prompt";
import InquirerAutocomplete = require("inquirer-autocomplete-prompt");
import { Interface as ReadlineInterface } from "readline";

export = InquirerFuzzyPath;

/**
 * Provides the functionality to create a new Inquirer plugin
 */
declare class InquirerFuzzyPath<T extends Answers> extends InquirerAutocomplete<T> {
    /**
     * Create new InquirerFuzzyPath
     *
     * @param questions
     * The questions to prompt
     * @param rl
     * The readline interface
     * @param answers
     * The currently supplied answers
     */
    constructor(questions: QuestionCollection<T>, rl: ReadlineInterface, answers: Answers);

    /**
     * Curate list of choices.
     *
     * @param searchTerm
     * The term to search for
     */
    search(searchTerm: string): Promise<void>;

    /**
     * When user presses `enter` key
     *
     * @param line
     * The input on the line.
     */
    onSubmit(line: string): void;
}

/**
 * Provides inquirer prompt options for type `InquirerFuzzyPath`.
 */
declare namespace InquirerFuzzyPath {
    /**
     * Provides options for a question of type `InquirerFuzzyPath`.
     *
     * @template T
     * The type of the answers.
     */
    interface FuzzyPathQuestionOptions<T extends Answers = Answers>
        extends Partial<Omit<AutocompleteQuestionOptions<T>, "type">>
    {
        /**
         * The key to save the answer to the answers-hash.
         */
        type: "fuzzypath";

        /**
         * The key to save the answer to the answers-hash.
         */
        name: KeyUnion<T>;

        /**
         * The root search directory, default to ".".
         */
        rootPath?: string | undefined;

        /**
         * A function to exclude some paths from the file-system scan.
         */
        excludePath?: ((path: string) => boolean) | undefined;

        /**
         * A function to exclude some paths from the final list.
         */
        excludeFilter?: ((path: string) => boolean) | undefined;

        /**
         * A string to specify the type of nodes to display, default to "any".
         */
        itemType?: "any" | "directory" | "file" | undefined;

        /**
         * An integer (>= 0) to limit the depth of sub-folders to scan,
         * undefined means infinite.
         */
        depthLimit?: number | undefined;
    }
}

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 03:09:37 GMT
 * Dependencies: [@types/inquirer](https://npmjs.com/package/@types/inquirer), [@types/inquirer-autocomplete-prompt](https://npmjs.com/package/@types/inquirer-autocomplete-prompt)

# Credits
These definitions were written by [迷子 (Maiko Tan)](https://github.com/MaikoTan).
